@@ -30,13 +30,13 @@ test_that("pairwise level comparison works", {
   draws = get_draws()
 
   draws_wide = spread(draws, ff, tau)
-  ref = plyr::ldply(combn(levels(draws$ff), 2, simplify = FALSE), function(levels.) {
-    draws_wide$ff = factor(paste(levels.[[2]], "-", levels.[[1]]))
+  ref = plyr::ldply(combn(levels(factor(draws$ff)), 2, simplify = FALSE), function(levels.) {
+    draws_wide$ff = paste(levels.[[2]], "-", levels.[[1]])
     draws_wide$tau = draws_wide[[levels.[[2]]]] - draws_wide[[levels.[[1]]]]
     draws_wide
   }) %>%
     select(-one_of(ff_labels)) %>%
-    as_tibble()
+    group_by(ff)
 
   expect_equal(compare_levels(draws, tau, by = ff, comparison = pairwise), ref)
   expect_equal(group_vars(compare_levels(draws, tau, by = ff, comparison = pairwise)), "ff")
@@ -49,12 +49,12 @@ test_that("ordered level comparison works", {
 
   draws_wide = spread(draws, ff, tau)
   ref = plyr::ldply(plyr::llply(2:3, function(i) c(ff_labels[[i]], ff_labels[[i - 1]])), function(levels.) {
-    draws_wide$ff = factor(paste(levels.[[1]], "-", levels.[[2]]))
+    draws_wide$ff = paste(levels.[[1]], "-", levels.[[2]])
     draws_wide$tau = draws_wide[[levels.[[1]]]] - draws_wide[[levels.[[2]]]]
     draws_wide
   }) %>%
     select(-one_of(ff_labels)) %>%
-    as_tibble()
+    group_by(ff)
 
   expect_equal(compare_levels(draws, tau, by = ff, comparison = ordered), ref)
   expect_equal(compare_levels(draws, tau, by = ff, comparison = "ordered"), ref)
@@ -65,12 +65,12 @@ test_that("control level comparison works", {
 
   draws_wide = spread(draws, ff, tau)
   ref = plyr::ldply(plyr::llply(2:3, function(i) c(ff_labels[[i]], ff_labels[[1]])), function(levels.) {
-    draws_wide$ff = factor(paste(levels.[[1]], "-", levels.[[2]]))
+    draws_wide$ff = paste(levels.[[1]], "-", levels.[[2]])
     draws_wide$tau = draws_wide[[levels.[[1]]]] - draws_wide[[levels.[[2]]]]
     draws_wide
   }) %>%
     select(-one_of(ff_labels)) %>%
-    as_tibble()
+    group_by(ff)
 
   expect_equal(compare_levels(draws, tau, by = ff, comparison = control), ref)
 })
@@ -92,12 +92,12 @@ test_that("named functions are supported and named with their own name", {
 
   draws_wide = spread(draws, ff, tau)
   ref = plyr::ldply(plyr::llply(2:3, function(i) c(ff_labels[[i]], ff_labels[[1]])), function(levels.) {
-    draws_wide$ff = factor(paste(levels.[[1]], "+", levels.[[2]]))
+    draws_wide$ff = paste(levels.[[1]], "+", levels.[[2]])
     draws_wide$tau = draws_wide[[levels.[[1]]]] + draws_wide[[levels.[[2]]]]
     draws_wide
   }) %>%
     select(-one_of(ff_labels)) %>%
-    as_tibble()
+    group_by(ff)
 
   expect_equal(compare_levels(draws, tau, by = ff, fun = `+`, comparison = control), ref)
 })
@@ -107,12 +107,12 @@ test_that("anonymous functions are supported and named with `:`", {
 
   draws_wide = spread(draws, ff, tau)
   ref = plyr::ldply(plyr::llply(2:3, function(i) c(ff_labels[[i]], ff_labels[[1]])), function(levels.) {
-    draws_wide$ff = factor(paste(levels.[[1]], ":", levels.[[2]]))
+    draws_wide$ff = paste(levels.[[1]], ":", levels.[[2]])
     draws_wide$tau = draws_wide[[levels.[[1]]]] + draws_wide[[levels.[[2]]]]
     draws_wide
   }) %>%
     select(-one_of(ff_labels)) %>%
-    as_tibble()
+    group_by(ff)
 
   expect_equal(compare_levels(draws, tau, by = ff, fun = function(x, y) x + y, comparison = control), ref)
 })
@@ -122,12 +122,12 @@ test_that("custom comparisons of lists of character vectors are supported", {
 
   draws_wide = spread(draws, ff, tau)
   ref = plyr::ldply(list(c("a", "b"), c("a", "c")), function(levels.) {
-    draws_wide$ff = factor(paste(levels.[[1]], "-", levels.[[2]]))
+    draws_wide$ff = paste(levels.[[1]], "-", levels.[[2]])
     draws_wide$tau = draws_wide[[levels.[[1]]]] - draws_wide[[levels.[[2]]]]
     draws_wide
   }) %>%
     select(-one_of(ff_labels)) %>%
-    as_tibble()
+    group_by(ff)
 
   expect_equal(compare_levels(draws, tau, by = ff, comparison = list(c("a", "b"), c("a", "c"))), ref)
 })
@@ -137,12 +137,12 @@ test_that("custom comparisons of lists of unevaluated expressions are supported"
 
   draws_wide = spread(draws, ff, tau)
   ref = plyr::ldply(plyr::.(a + b, exp(c - a)), function(levels.) {
-    draws_wide$ff = factor(deparse0(levels.))
+    draws_wide$ff = deparse0(levels.)
     draws_wide$tau = eval(levels., draws_wide)
     draws_wide
   }) %>%
     select(-one_of(ff_labels)) %>%
-    as_tibble()
+    group_by(ff)
 
   expect_equal(compare_levels(draws, tau, by = ff, comparison = plyr::.(a + b, exp(c - a))), ref)
   expect_equal(compare_levels(draws, tau, by = ff, comparison = rlang::exprs(a + b, exp(c - a))), ref)
@@ -154,12 +154,12 @@ test_that("comparisons of subsets of levels of factors are supported", {
 
   draws_wide = spread(draws, ff, tau)
   ref = plyr::ldply(combn(levels(factor(draws$ff)), 2, simplify = FALSE), function(levels.) {
-    draws_wide$ff = factor(paste(levels.[[2]], "-", levels.[[1]]))
+    draws_wide$ff = paste(levels.[[2]], "-", levels.[[1]])
     draws_wide$tau = draws_wide[[levels.[[2]]]] - draws_wide[[levels.[[1]]]]
     draws_wide
   }) %>%
     select(-one_of(c("a", "c"))) %>%
-    as_tibble()
+    group_by(ff)
 
   expect_equal(compare_levels(draws, tau, by = ff, comparison = pairwise), ref)
 })
@@ -185,7 +185,7 @@ test_that("compare_levels respects groups of input data frame", {
   ref = plyr::ddply(draws, "i", function (d) {
     draws_wide = spread(d, j, b)
     plyr::ldply(combn(levels(factor(d$j)), 2, simplify = FALSE), function(levels.) {
-      draws_wide$j = factor(paste(levels.[[2]], "-", levels.[[1]]))
+      draws_wide$j = paste(levels.[[2]], "-", levels.[[1]])
       draws_wide$b = draws_wide[[levels.[[2]]]] - draws_wide[[levels.[[1]]]]
       draws_wide
     })
