@@ -12,13 +12,13 @@ context("unspread_draws")
 test_that("unspread_draws works on a simple parameter with no dimensions", {
   data(RankCorr, package = "tidybayes")
 
-  ref = data_frame(
+  ref = tibble(
       .chain = as.integer(1),
       .iteration = seq_len(nrow(RankCorr[[1]])),
       .draw = seq_len(nrow(RankCorr[[1]])),
       typical_r = as.vector(RankCorr[[1]][, "typical_r"])
     ) %>%
-    bind_rows(data_frame(
+    bind_rows(tibble(
       .chain = as.integer(2),
       .iteration = seq_len(nrow(RankCorr[[2]])),
       .draw = nrow(RankCorr[[2]]) + seq_len(nrow(RankCorr[[2]])),
